summaryrefslogtreecommitdiff
path: root/src/home/inverter/monitor.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/home/inverter/monitor.py')
-rw-r--r--src/home/inverter/monitor.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/home/inverter/monitor.py b/src/home/inverter/monitor.py
index 952b8c8..3835365 100644
--- a/src/home/inverter/monitor.py
+++ b/src/home/inverter/monitor.py
@@ -271,7 +271,7 @@ class InverterMonitor(Thread):
if self.next_current_enter_time != 0 and pd != BatteryPowerDirection.CHARGING:
# Generator was warming up and charging, but stopped (pd has changed).
# Resetting to the minimum possible pd
logger.info(f'gen_charging_program (warming path): was charging but power direction suddeny changed. resetting to minimum current')
self.next_current_enter_time = 0
self.gen_next_current(current=self.min_allowed_current)
@@ -355,6 +355,8 @@ class InverterMonitor(Thread):
self.floating_stopwatch.reset()
self.current_change_direction = CurrentChangeDirection.UP
+ self.set_hw_charging_current(self.min_allowed_current)
+
def gen_next_current(self, current=None):
if current is None:
try:
@@ -271,7 +271,7 @@ class InverterMonitor(Thread):
if self.next_current_enter_time != 0 and pd != BatteryPowerDirection.CHARGING:
# Generator was warming up and charging, but stopped (pd has changed).
- # Resetting to the minimum possible pd
+ # Resetting to the minimum possible current
logger.info(f'gen_charging_program (warming path): was charging but power direction suddeny changed. resetting to minimum current')
self.next_current_enter_time = 0